Documentation
¶
Overview ¶
Package cmd provides the commands to call Zettelstore from the command line.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterCommand ¶
func RegisterCommand(cmd Command)
RegisterCommand registers the given command.
Types ¶
type Command ¶
type Command struct {
Name string // command name as it appears on the command line
Func CommandFunc // function that executes a command
Simple bool // Operate in simple-mode
Boxes bool // if true then boxes will be set up
Header bool // Print a heading on startup
LineServer bool // Start admin line server
SetFlags func(*flag.FlagSet) // function to set up flag.FlagSet
// contains filtered or unexported fields
}
Command stores information about commands / sub-commands.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package main is the starting point for the zettelstore command.
|
Package main is the starting point for the zettelstore command. |
Click to show internal directories.
Click to hide internal directories.